import { jsxs, jsx } from 'react/jsx-runtime';
import { css } from '@emotion/css';
import { useMemo, useRef, useState, useLayoutEffect } from 'react';
import { TableCellDisplayMode } from '@grafana/schema';
import '@grafana/data';
import { useStyles2 } from '../../../../themes/ThemeContext.mjs';
import 'micro-memoize';
import '@emotion/react';
import 'tinycolor2';
import '../../../../utils/skeleton.mjs';
import { IconButton } from '../../../IconButton/IconButton.mjs';
import { TableCellInspectorMode } from '../../TableCellInspector.mjs';
import { getTextAlign, getCellColors } from '../utils.mjs';
import { ActionsCell } from './ActionsCell.mjs';
import AutoCell from './AutoCell.mjs';
import { BarGaugeCell } from './BarGaugeCell.mjs';
import { DataLinksCell } from './DataLinksCell.mjs';
import { ImageCell } from './ImageCell.mjs';
import { JSONCell } from './JSONCell.mjs';
import { SparklineCell } from './SparklineCell.mjs';

function TableCellNG(props) {
  var _a, _b;
  const {
    field,
    frame,
    value,
    theme,
    timeRange,
    height,
    rowIdx,
    justifyContent,
    shouldTextOverflow,
    setIsInspecting,
    setContextMenuProps,
    cellInspect,
    getActions,
    rowBg
  } = props;
  const { config: fieldConfig } = field;
  const defaultCellOptions = { type: TableCellDisplayMode.Auto };
  const cellOptions = (_b = (_a = fieldConfig.custom) == null ? void 0 : _a.cellOptions) != null ? _b : defaultCellOptions;
  const { type: cellType } = cellOptions;
  const isRightAligned = getTextAlign(field) === "flex-end";
  const displayValue = field.display(value);
  let colors = { bgColor: "", textColor: "", bgHoverColor: "" };
  if (rowBg) {
    colors = rowBg(rowIdx);
  } else {
    colors = useMemo(() => getCellColors(theme, cellOptions, displayValue), [theme, cellOptions, displayValue]);
  }
  const styles = useStyles2(getStyles, isRightAligned, colors);
  const divWidthRef = useRef(null);
  const [divWidth, setDivWidth] = useState(0);
  const [isHovered, setIsHovered] = useState(false);
  const actions = getActions ? getActions(frame, field, rowIdx) : [];
  useLayoutEffect(() => {
    if (divWidthRef.current && divWidthRef.current.clientWidth !== 0) {
      setDivWidth(divWidthRef.current.clientWidth);
    }
  }, [divWidthRef.current]);
  let cell = null;
  switch (cellType) {
    case TableCellDisplayMode.Sparkline:
      cell = /* @__PURE__ */ jsx(
        SparklineCell,
        {
          value,
          field,
          theme,
          timeRange,
          width: divWidth,
          rowIdx,
          justifyContent
        }
      );
      break;
    case TableCellDisplayMode.Gauge:
    case TableCellDisplayMode.BasicGauge:
    case TableCellDisplayMode.GradientGauge:
    case TableCellDisplayMode.LcdGauge:
      cell = /* @__PURE__ */ jsx(
        BarGaugeCell,
        {
          value,
          field,
          theme,
          timeRange,
          height,
          width: divWidth,
          rowIdx
        }
      );
      break;
    case TableCellDisplayMode.Image:
      cell = /* @__PURE__ */ jsx(
        ImageCell,
        {
          cellOptions,
          field,
          height,
          justifyContent,
          value,
          rowIdx
        }
      );
      break;
    case TableCellDisplayMode.JSONView:
      cell = /* @__PURE__ */ jsx(JSONCell, { value, justifyContent, field, rowIdx });
      break;
    case TableCellDisplayMode.DataLinks:
      cell = /* @__PURE__ */ jsx(DataLinksCell, { field, rowIdx });
      break;
    case TableCellDisplayMode.Actions:
      cell = /* @__PURE__ */ jsx(ActionsCell, { actions });
      break;
    case TableCellDisplayMode.Auto:
    default:
      cell = /* @__PURE__ */ jsx(
        AutoCell,
        {
          value,
          field,
          justifyContent,
          rowIdx,
          cellOptions
        }
      );
  }
  const handleMouseEnter = () => {
    setIsHovered(true);
    if (shouldTextOverflow()) {
      const div = divWidthRef.current;
      const tableCellDiv = div == null ? void 0 : div.parentElement;
      tableCellDiv == null ? void 0 : tableCellDiv.style.setProperty("position", "absolute");
      tableCellDiv == null ? void 0 : tableCellDiv.style.setProperty("top", "0");
      tableCellDiv == null ? void 0 : tableCellDiv.style.setProperty("z-index", String(theme.zIndex.tooltip));
      tableCellDiv == null ? void 0 : tableCellDiv.style.setProperty("white-space", "normal");
      tableCellDiv == null ? void 0 : tableCellDiv.style.setProperty("min-height", `${height}px`);
    }
  };
  const handleMouseLeave = () => {
    setIsHovered(false);
    if (shouldTextOverflow()) {
      const div = divWidthRef.current;
      const tableCellDiv = div == null ? void 0 : div.parentElement;
      tableCellDiv == null ? void 0 : tableCellDiv.style.setProperty("position", "relative");
      tableCellDiv == null ? void 0 : tableCellDiv.style.removeProperty("top");
      tableCellDiv == null ? void 0 : tableCellDiv.style.removeProperty("z-index");
      tableCellDiv == null ? void 0 : tableCellDiv.style.setProperty("white-space", "nowrap");
    }
  };
  return /* @__PURE__ */ jsxs("div", { ref: divWidthRef, onMouseEnter: handleMouseEnter, onMouseLeave: handleMouseLeave, className: styles.cell, children: [
    cell,
    cellInspect && isHovered && /* @__PURE__ */ jsx("div", { className: styles.cellActions, children: /* @__PURE__ */ jsx(
      IconButton,
      {
        name: "eye",
        tooltip: "Inspect value",
        onClick: () => {
          setContextMenuProps({
            value: String(value != null ? value : ""),
            mode: cellType === TableCellDisplayMode.JSONView ? TableCellInspectorMode.code : TableCellInspectorMode.text
          });
          setIsInspecting(true);
        }
      }
    ) })
  ] });
}
const getStyles = (theme, isRightAligned, color) => ({
  cell: css({
    height: "100%",
    alignContent: "center",
    paddingInline: "8px",
    // TODO: follow-up on this: change styles on hover on table row level
    background: color.bgColor || "none",
    color: color.textColor,
    "&:hover": { background: color.bgHoverColor }
  }),
  cellActions: css({
    display: "flex",
    position: "absolute",
    top: "1px",
    left: isRightAligned ? 0 : void 0,
    right: isRightAligned ? void 0 : 0,
    margin: "auto",
    height: "100%",
    background: theme.colors.background.secondary,
    color: theme.colors.text.primary,
    padding: "4px 0px 4px 4px"
  })
});

export { TableCellNG };
//# sourceMappingURL=TableCellNG.mjs.map
